==> aliyun-sdk-oss-2.8.3-sources.jar: com/aliyun/oss/model/CreateSymlinkRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.aliyun.oss.model;

/**
 * The request class that is used to create symlink on an object.
 * 
 */
public class CreateSymlinkRequest extends GenericRequest {
    
    public CreateSymlinkRequest(String bucketName, String symlink, 
            String target) {
        super(bucketName, symlink);
        this.target = target;
    }
    
    public String getSymlink() {
        return this.getKey();
    }

    public void setSymlink(String symlink) {
        this.setKey(symlink);
    }

    /**
     * Sets the target file of the symlink.
     * @return Target file.
     */
    public String getTarget() {
        return this.target;
    }

    /**
     * Gets the target file of the symlink.
     * @param target Target file.
     */
    public void setTarget(String target) {
        this.target = target;
    }
    
    /**
     * Gets the symlink file's metadata.
     * @return symlink file's metadata.
     */
    public ObjectMetadata getMetadata() {
        return metadata;
    }

    /**
     * Sets the symlink file's metadata.
     * @param metadata symlink file's metadata.
     */
    public void setMetadata(ObjectMetadata metadata) {
        this.metadata = metadata;
    }

    // Target file.
    private String target;
    
    // symlink file's metadata.
    private ObjectMetadata metadata;
}

==> aliyun-sdk-oss-3.11.2-sources.jar: com/aliyun/oss/model/CreateSymlinkRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.aliyun.oss.model;

/**
 * The request class that is used to create symlink on an object.
 * 
 */
public class CreateSymlinkRequest extends GenericRequest {

    public CreateSymlinkRequest(String bucketName, String symlink, String target) {
        super(bucketName, symlink);
        this.target = target;
    }

    public String getSymlink() {
        return this.getKey();
    }

    public void setSymlink(String symlink) {
        this.setKey(symlink);
    }

    /**
     * Sets the target file of the symlink.
     * 
     * @return Target file.
     */
    public String getTarget() {
        return this.target;
    }

    /**
     * Gets the target file of the symlink.
     * 
     * @param target
     *            Target file.
     */
    public void setTarget(String target) {
        this.target = target;
    }

    /**
     * Gets the symlink file's metadata.
     * 
     * @return symlink file's metadata.
     */
    public ObjectMetadata getMetadata() {
        return metadata;
    }

    /**
     * Sets the symlink file's metadata.
     * 
     * @param metadata
     *            symlink file's metadata.
     */
    public void setMetadata(ObjectMetadata metadata) {
        this.metadata = metadata;
    }

    // Target file.
    private String target;

    // symlink file's metadata.
    private ObjectMetadata metadata;
}
